==> qmmp-0.12.14.tar.bz2: qmmp-0.12.14/src/plugins/Input/gme/translations/gme_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>DecoderGmeFactory</name>
    <message>
        <location filename="../decodergmefactory.cpp" line="38"/>
        <source>GME Plugin</source>
        <translation>Plugin GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="41"/>
        <source>Game Music Files</source>
        <translation>File Musik Game</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="103"/>
        <source>About GME Audio Plugin</source>
        <translation>Tentang Plugin Audio GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="104"/>
        <source>Qmmp GME Audio Plugin</source>
        <translation>Plugin Audio GME Qmmp</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="105"/>
        <source>This plugin uses Game_Music_Emu library to play game music files</source>
        <translation>Plugin ini menggunakan pustaka Game_Music_Emu untuk memainkan file musik game</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="106"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>GME Plugin Settings</source>
        <translation>Setelan Plugin GME</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Fadeout length:</source>
        <translation>Panjang fadeout:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>ms</source>
        <translation>md</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Enable fadeout</source>
        <translation>Aktifkan fadeout</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Input/gme/translations/gme_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>DecoderGmeFactory</name>
    <message>
        <location filename="../decodergmefactory.cpp" line="39"/>
        <source>GME Plugin</source>
        <translation>Plugin GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="42"/>
        <source>Game Music Files</source>
        <translation>File Musik Game</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="106"/>
        <source>About GME Audio Plugin</source>
        <translation>Tentang Plugin Audio GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="107"/>
        <source>Qmmp GME Audio Plugin</source>
        <translation>Plugin Audio GME Qmmp</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="108"/>
        <source>This plugin uses Game_Music_Emu library to play game music files</source>
        <translation>Plugin ini menggunakan pustaka Game_Music_Emu untuk memainkan file musik game</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="109"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>GME Plugin Settings</source>
        <translation>Setelan Plugin GME</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Fadeout length:</source>
        <translation>Panjang fadeout:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>ms</source>
        <translation>md</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Enable fadeout</source>
        <translation>Aktifkan fadeout</translation>
    </message>
</context>
</TS>
